# Set

::::{grid} 1 2 2 3
:margin: 4 4 0 0
:gutter: 1

:::{grid-item-card} {octicon}`cpu` Documentation
:link: setListing
:link-type: doc

View the API and documentation for LibRapid Sets.
:::

:::{grid-item-card} {octicon}`tools` Examples
:link: examples
:link-type: doc

See some examples of LibRapid's Set library in action
:::

:::{grid-item-card} {octicon}`tools` Implementation Details
:link: implementation
:link-type: doc

Learn about how LibRapid's Set library is implemented
:::
::::

```{toctree}
    :hidden:
    :maxdepth: 3
    
    Documentation <setListing>
    Examples <examples>
    Implementation Details <implementation>
```
